import greenfoot.*;

public class DropDownMenu extends Actor
{
    GreenfootImage[] itemImgs;
    private String[] items;
    public MenuItem[] actors;
    private int selection;
    private int wide;
    
    public DropDownMenu(String[] menuItems, int defaultSelection)
    {
        items = menuItems;
        actors = new MenuItem[items.length];
        itemImgs = new GreenfootImage[items.length];
        GreenfootImage[] images = new GreenfootImage[items.length];
        for (int i=0; i<actors.length; i++)
        {
            images[i] = new GreenfootImage(items[i], 20, Color.BLACK, new Color(0, 0, 0, 0));
            wide = Math.max(wide, images[i].getWidth());
        }
        for (int i=0; i<actors.length; i++)
        {
            itemImgs[i] = new GreenfootImage(wide+4, 24);
            itemImgs[i].drawRect(0, 0, wide+3, 23);
            itemImgs[i].drawImage(images[i], 2, 2);
            actors[i] = new MenuItem(i);
        }
        setSelection(defaultSelection);
    }
    
    public void act()
    {
        if (Greenfoot.mouseClicked(this))
        {
            if (actors[0].getWorld() == getWorld()) setSelection(selection); else showItems();
        }
    }
    
    public void showItems()
    {
        for (int i=0; i<actors.length; i++) getWorld().addObject(actors[i], getX(), getY()+24*(i+1));
    }
    
    public void setSelection(int selected)
    {
        selection = (selected%items.length+items.length)%items.length;
        GreenfootImage img = new GreenfootImage(wide+4, 24);
        img.setColor(Color.CYAN);
        img.fill();
        img.drawImage(itemImgs[selection], 0, 0);
        setImage(img);
        if (getWorld() != null) getWorld().removeObjects(java.util.Arrays.asList(actors));
    }
    
    public int getSelection()
    {
        return selection;
    }
    
    public class MenuItem extends Actor
    {
        private int id;
        
        public MenuItem(int num)
        {
            id = num;
            GreenfootImage img = new GreenfootImage(wide+4, 24);
            img.setColor(Color.WHITE);
            img.fill();
            img.drawImage(itemImgs[id], 0, 0);
            setImage(img);
        }
        
        public void act()
        {
            if (Greenfoot.mouseClicked(this)) setSelection(id);
        }
    }
}